@@ -35,21 +35,21 @@ typedef struct {
 } SpeedyBuf;
 
 int speedy_util_pref_fd(int oldfd, int newfd);
-SPEEDY_INLINE int speedy_util_getuid();
-SPEEDY_INLINE int speedy_util_geteuid();
+SPEEDY_INLINE int speedy_util_getuid(void);
+SPEEDY_INLINE int speedy_util_geteuid(void);
 int speedy_util_seteuid(int id);
 int speedy_util_argc(const char * const * argv);
-SPEEDY_INLINE int speedy_util_getpid();
-void speedy_util_pid_invalidate();
+SPEEDY_INLINE int speedy_util_getpid(void);
+void speedy_util_pid_invalidate(void);
 void speedy_util_die(const char *fmt, ...);
 void speedy_util_die_quiet(const char *fmt, ...);
 int speedy_util_execvp(const char *filename, const char *const *argv);
 char *speedy_util_strndup(const char *s, int len);
-SPEEDY_INLINE int speedy_util_time();
+SPEEDY_INLINE int speedy_util_time(void);
 SPEEDY_INLINE void speedy_util_gettimeofday(struct timeval *tv);
-SPEEDY_INLINE void speedy_util_time_invalidate();
+void speedy_util_time_invalidate(void);
 char *speedy_util_fname(int num, char type);
-char *speedy_util_getcwd();
+char *speedy_util_getcwd(void);
 SpeedyMapInfo *speedy_util_mapin(int fd, int max_size, int file_size);
 void speedy_util_mapout(SpeedyMapInfo *mi);
 SPEEDY_INLINE SpeedyDevIno speedy_util_stat_devino(const struct stat *stbuf);
@@ -73,3 +73,23 @@ int speedy_util_kill(pid_t pid, int sig);
 #else
 #define PREF_FD_FILE		PREF_FD_DONTCARE
 #endif
+
+#ifdef SPEEDY_DEBUG
+
+#if !defined(RLIM_INFINITY) || !defined(RLIMIT_CORE)
+#include <sys/resource.h>
+#endif
+
+#define speedy_util_unlimit_core() \
+    { \
+	struct rlimit rlimitvals; \
+	rlimitvals.rlim_cur = RLIM_INFINITY; \
+	rlimitvals.rlim_max = RLIM_INFINITY; \
+	setrlimit(RLIMIT_CORE, &rlimitvals); \
+    }
+
+#else
+
+#define speedy_util_unlimit_core()
+
+#endif /* SPEEDY_DEBUG */
